@@ -12,40 +12,33 @@ from typing import overload
 from . import _log
 from . import version
 
+__all__ = [
+    "entry_points",
+    "im",
+]
 if TYPE_CHECKING:
     from . import _types as _t
     from ._config import Configuration
     from ._config import ParseFunction
 
-
-from importlib.metadata import EntryPoint as EntryPoint
-
-if sys.version_info[:2] < (3, 10):
-    from importlib.metadata import entry_points as legacy_entry_points
-
-    class EntryPoints:
-        _groupdata: list[EntryPoint]
-
-        def __init__(self, groupdata: list[EntryPoint]) -> None:
-            self._groupdata = groupdata
-
-        def select(self, name: str) -> EntryPoints:
-            return EntryPoints([x for x in self._groupdata if x.name == name])
-
-        def __iter__(self) -> Iterator[EntryPoint]:
-            return iter(self._groupdata)
-
-    def entry_points(group: str) -> EntryPoints:
-        return EntryPoints(legacy_entry_points()[group])
-
-else:
-    from importlib.metadata import EntryPoints
-    from importlib.metadata import entry_points
+    if sys.version_info[:2] < (3, 10):
+        import importlib_metadata as im
+    else:
+        from importlib import metadata as im
 
 
 log = _log.log.getChild("entrypoints")
 
 
+def entry_points(**kw: Any) -> im.EntryPoints:
+    if sys.version_info[:2] < (3, 10):
+        import importlib_metadata as im
+    else:
+        import importlib.metadata as im
+
+    return im.entry_points(**kw)
+
+
 def version_from_entrypoint(
     config: Configuration, *, entrypoint: str, root: _t.PathT
 ) -> version.ScmVersion | None:
@@ -61,23 +54,17 @@ def version_from_entrypoint(
     return None
 
 
-def iter_entry_points(group: str, name: str | None = None) -> Iterator[EntryPoint]:
-    eps: EntryPoints = entry_points(group=group)
-    res = eps if name is None else eps.select(name=name)
-
-    return iter(res)
-
-
 def _get_ep(group: str, name: str) -> Any | None:
-    for ep in iter_entry_points(group, name):
+    for ep in entry_points(group=group, name=name):
         log.debug("ep found: %s", ep.name)
         return ep.load()
-    else:
-        return None
+    return None
 
 
 def _get_from_object_reference_str(path: str, group: str) -> Any | None:
     # todo: remove for importlib native spelling
+    from importlib.metadata import EntryPoint  # hack
+
     ep = EntryPoint(path, path, group)
     try:
         return ep.load()
